"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 *  Error subclass for signaling keystore errors
 */
class KeystoreError extends Error {
    constructor(message) {
        super(message);
        this.name = this.constructor.name;
        Error.captureStackTrace(this, this.constructor);
        Object.setPrototypeOf(this, KeystoreError.prototype);
    }
}
exports.KeystoreError = KeystoreError;
/**
 *  Error subclass for signaling keystore error when a given private key is not found
 */
class PrivateKeyNotFoundError extends KeystoreError {
    constructor(keyId) {
        super(`private key not found, key id: ${keyId}`);
        this.keyId = keyId;
        Object.setPrototypeOf(this, PrivateKeyNotFoundError.prototype);
    }
}
exports.PrivateKeyNotFoundError = PrivateKeyNotFoundError;
/**
 *  Error subclass for signaling keystore error when a given public key is not found
 */
class CertificateNotFoundError extends KeystoreError {
    constructor(keyId) {
        super(`certificate not found, key id: ${keyId}`);
        this.keyId = keyId;
        Object.setPrototypeOf(this, CertificateNotFoundError.prototype);
    }
}
exports.CertificateNotFoundError = CertificateNotFoundError;
//# sourceMappingURL=errors.js.map