"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai = __importStar(require("chai"));
const chai_1 = require("chai");
const path = __importStar(require("path"));
const keystore_reader_fs_1 = require("./keystore.reader.fs");
const chaiAsPromised = require("chai-as-promised");
const dirtyChai = require("dirty-chai");
chai.use(chaiAsPromised);
chai.use(dirtyChai);
const debugName = 'keystore';
describe('keystoreReaderFs', () => {
    const keys = new Map();
    it('Should read all RSA keys in a directory', async () => {
        const baseDir = path.join(__dirname, '/../test/keys_ca/rsa');
        const keystoreReaderFs = new keystore_reader_fs_1.KeystoreReaderFs(debugName, baseDir);
        const newKeys = await keystoreReaderFs.readKeys(keys);
        newKeys.forEach(key => {
            chai_1.expect(key).has.property('timestamp');
            chai_1.expect(key).has.property('cert');
            chai_1.expect(key).has.property('privKey');
            chai_1.expect(key).has.property('pubkeyJwk');
            chai_1.expect(key.pubkeyJwk).has.property('kid');
            chai_1.expect(key.pubkeyJwk.kty).to.equal('RSA');
            chai_1.expect(key.pubkeyJwk).has.property('n');
            chai_1.expect(key.pubkeyJwk).has.property('e');
            chai_1.expect(key.pubkeyJwk.alg).to.equal('RS256');
            chai_1.expect(key.pubkeyJwk.use).to.equal('sig');
            chai_1.expect(key.pubkeyJwk).has.property('x5c');
        });
        chai_1.expect(newKeys.has('1')).to.be.true();
        chai_1.expect(newKeys.has('2')).to.be.true();
        chai_1.expect(newKeys.has('3')).to.be.true();
        chai_1.expect(newKeys.size).to.equal(3);
    });
    it('Should read all ECDSA keys in a directory', async () => {
        const baseDir = path.join(__dirname, '/../test/keys_ca/ecdsa');
        const keystoreReaderFs = new keystore_reader_fs_1.KeystoreReaderFs(debugName, baseDir);
        const newKeys = await keystoreReaderFs.readKeys(keys);
        newKeys.forEach(key => {
            chai_1.expect(key).has.property('timestamp');
            chai_1.expect(key).has.property('cert');
            chai_1.expect(key).has.property('privKey');
            chai_1.expect(key).has.property('pubkeyJwk');
            chai_1.expect(key.pubkeyJwk).has.property('kid');
            chai_1.expect(key.pubkeyJwk.kty).to.equal('EC');
            chai_1.expect(key.pubkeyJwk.crv).to.equal('P-256');
            chai_1.expect(key.pubkeyJwk).has.property('x');
            chai_1.expect(key.pubkeyJwk).has.property('y');
            chai_1.expect(key.pubkeyJwk.alg).to.equal('ES256');
            chai_1.expect(key.pubkeyJwk.use).to.equal('sig');
            chai_1.expect(key.pubkeyJwk).has.property('x5c');
        });
        chai_1.expect(newKeys.has('1')).to.be.true();
        chai_1.expect(newKeys.has('2')).to.be.true();
        chai_1.expect(newKeys.has('3')).to.be.true();
        chai_1.expect(newKeys.size).to.equal(3);
    });
    it('Should fail if a wrong directory is passed', function () {
        const fakeBaseDir = path.join(__dirname, '/../test/keys_ca/_fake_');
        chai_1.expect(() => new keystore_reader_fs_1.KeystoreReaderFs('keystore', fakeBaseDir)).to.throw(Error, /ENOENT/);
    });
});
//# sourceMappingURL=keystore.reader.fs.spec.js.map